package doctor.controller;

import doctor.common.core.domain.HealthR;
import doctor.domain.vo.DoctorVo;
import doctor.domain.vo.InquiryDetailsRecordVo;
import doctor.service.InquiryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.actuate.health.Health;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static com.github.pagehelper.page.PageMethod.startPage;

/**
 * @ClassName : InquiryController
 * @Description : 问诊
 * @Author : FJJ
 * @Date: 2024-01-12 19:09
 */
@RestController
@RequestMapping("/user/inquiry")
public class InquiryController {
    @Autowired
    private InquiryService inquiryService;
    //历史问诊记录列表
    @GetMapping("/verify/v1/findHistoryInquiryRecord")
    public HealthR<List<InquiryDetailsRecordVo>> findHistoryInquiryRecord(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<InquiryDetailsRecordVo> inquiryDetailsRecordVoList = inquiryService.findHistoryInquiryRecord();
        return HealthR.ok(inquiryDetailsRecordVoList);
    }

    @GetMapping("/v1/findDoctorInfo")
    public HealthR<DoctorVo> findDoctorInfo(@RequestHeader Integer userId,
                                            @RequestHeader String sessionId,
                                            @RequestParam(value = "doctorId",defaultValue = "2") Integer doctorId) {
        DoctorVo doctorVo = inquiryService.findDoctorInfo(doctorId);
        return HealthR.ok(doctorVo);
    }

    //咨询医生
    @PutMapping("/verify/v1/consultDoctor")
    public HealthR consultDoctor(@RequestHeader Integer userId,
                                                  @RequestHeader String sessionId,
                                                  @RequestParam Integer doctorId){
        String doctorUserName = inquiryService.consultDoctor(userId,doctorId);
        return HealthR.ok(doctorUserName);
    }

    //关注医生
    @PostMapping("/verify/v1/followDoctor")
    public HealthR followDoctor(@RequestHeader Integer userId,
                                @RequestHeader String sessionId,
                                @RequestParam Integer doctorId) {
        inquiryService.followDoctor(userId,doctorId);
        return HealthR.ok();
    }

    //取消关注医生
   @DeleteMapping("/verify/v1/cancelFollow")
    public HealthR cancelFollow(@RequestHeader Integer userId,
                                @RequestHeader String sessionId,
                                @RequestParam Integer doctorId){
        inquiryService.cancelFollow(userId,doctorId);
        return HealthR.ok();
   }

   //结束问诊
   @PutMapping("/verify/v1/endInquiry")
    public HealthR endInquiry(@RequestHeader Integer userId,
                                        @RequestHeader String sessionId,
                                        @RequestParam Integer recordId) {
        inquiryService.endInquiry(userId,recordId);
        return HealthR.ok();
   }
}
