package doctor.controller;

import com.alibaba.nacos.api.model.v2.Result;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import doctor.common.core.domain.HealthR;
import doctor.domain.entity.SickCircleEntity;
import doctor.domain.entity.SickCommentEntity;
import doctor.domain.entity.SymptomEntity;
import doctor.domain.vo.SearchSickCircleVo;
import doctor.domain.vo.SickCircleVo;
import doctor.domain.vo.SickCommentVo;
import doctor.domain.vo.SickInfoVo;
import doctor.service.PatientService;
import doctor.service.SickCircleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName PatientController
 * @Description 描述
 * @Author 栗永斌
 */
@RestController
@RequestMapping("/sickCircle/v1/")
public class PatientController {

    @Autowired
    private PatientService patientService;

    @Autowired
    private SickCircleService sickCircleService;

    /**
     * 发表评论
     */
    @PostMapping("/publishComment")
    public Result<SickCommentVo> publishComment(
            @RequestParam("sickCircleId") Integer sickCircleId,
            @RequestParam("content") String content) {

        return sickCircleService.publishComment(sickCircleId, content);
    }


    /**
     * 点采
     * @param opinion
     * @return
     */
    @PutMapping("expressOpinion")
    public HealthR expressOpinion(@RequestParam("opinion") Integer opinion){
//        return sickCircleServer.expressOpinion(commentId, opinion);
        System.out.println(opinion);
        return null;
    }

    /**
     * 新增病友圈
     */
    @PostMapping("/publishSickCircle")
    public HealthR<SickCircleEntity> publishSickCircle(@RequestBody SickCircleEntity sickCircleEntity) {

        return sickCircleService.publishSickCircle(sickCircleEntity);
    }

    /**
     * 病友圈列表
     *
     * @param departmentId
     * @return
     */
    @GetMapping("/findSickCircleList")
    public HealthR<List<SickCircleEntity>> sickCircleList(@RequestParam(value = "departmentId",required = false) Integer departmentId,
                                                          @RequestParam(value = "page") Integer page,
                                                          @RequestParam(value = "count") Integer count) {
        return  patientService.sickCircleList(departmentId,page,count);
    }

    private PageInfo<SickCircleEntity> startPage(Integer page, Integer count) {
        Page<SickCircleEntity> objects = PageHelper.startPage(page, count);
         return  new PageInfo<>(objects);
    }

    /**
     * 病友圈详情
     */
    @GetMapping("/findSickCircleInfo")
    public HealthR<SickCircleEntity> findSickCircleInfo(@RequestParam("sickCircleId") Integer sickCircleId) {
        SickCircleEntity sickCircleEntity = patientService.findSickCircleInfo(sickCircleId);
        return HealthR.ok(sickCircleEntity);
    }

    /**
     * 病症列表
     */
    @GetMapping("/symptomList")
    public Result<List<SymptomEntity>> symptomList() {
        return patientService.symptomList();
    }


    /**
     * 查询病友圈评论列表
     */
    @GetMapping("/findSickCircleCommentList")
    public HealthR<List<SickCommentEntity>> findSickCircleCommentList(@RequestParam(value = "sickCircleId",required = false) Integer sickCircleId,
                                                                      @RequestParam(value = "page",defaultValue = "1") Integer page,
                                                                      @RequestParam(value = "count",defaultValue = "10") Integer count) {
         startPage(page, count);
        return  patientService.findSickCircleCommentList(sickCircleId);
    }


    /**
     * 搜索病友圈
     * @param keyWord
     * @return
     */
    @GetMapping("searchSickCircle")
    public HealthR<List<SickCircleEntity>> searchSickCircle(@RequestParam(value = "keyWord",required = false) String keyWord){
        return patientService.searchSickCircle(keyWord);

    }
}
