package doctor.controller;

import doctor.common.core.domain.HealthR;
import doctor.domain.dto.UserArchivesDto;
import doctor.domain.entity.*;
import doctor.domain.vo.*;
import doctor.service.UserVideoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.List;

import static com.github.pagehelper.page.PageMethod.startPage;


/**
 * @ClassName : UserVideoController
 * @Description : 用户视频
 * @Author : FJJ
 * @Date: 2024-01-10 14:32
 */
@RestController
@RequestMapping("/user/verify/v1")
public class UserVideoController {
    @Autowired
        private UserVideoService userVideoService;

    //用户视频收藏列表
    @GetMapping("/findVideoCollectionList")
    public HealthR<List<UserVideoCollectionVo>> findVideoCollectionList(@RequestParam Integer page, @RequestParam Integer count,@RequestHeader Integer userId){
        startPage(page,count);
      List<UserVideoCollectionVo>  userVideoCollectionVos=userVideoService.findVideoCollectionList(userId);
        return HealthR.ok(userVideoCollectionVos);
    }
    //用户取消视频收藏
    @DeleteMapping("/cancelVideoCollection")
    public HealthR cancelVideoCollection(@RequestHeader Integer userId,@RequestHeader String sessionId,@RequestParam Integer videoId ){
        userVideoService.cancelVideoCollection(userId,sessionId,videoId);
        return HealthR.ok();
    }
    //用户购买视频列表
    @GetMapping("/findUserVideoBuyList")
    public HealthR<List<UserVideoBuyVo>>findUserVideoBuyList(@RequestParam Integer page, @RequestParam Integer count){
        startPage(page,count);
        List<UserVideoBuyVo> userVideoCollectionVos =userVideoService.findUserVideoBuyList();
        return HealthR.ok(userVideoCollectionVos);
    }
    //用户删除购买的视频
    @DeleteMapping("/deleteVideoBuy")
    public HealthR deleteVideoBuy(@RequestParam Integer videoId){
        userVideoService.deleteVideoBuy(videoId);
        return HealthR.ok();
    }

    //我的钱包
    @GetMapping("/findUserWallet")
    public HealthR findUserWallet(@RequestHeader Integer userId){
        Integer i= userVideoService.findUserWallet(userId);
        return HealthR.ok(i);
    }
    //用户消费记录
    @GetMapping("/findUserConsumptionRecordList")
    public HealthR<List<UserConsumptionRecordVo>> findUserConsumptionRecordList(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<UserConsumptionRecordVo> userConsumptionRecordVos = userVideoService.findUserConsumptionRecordList();
        return HealthR.ok(userConsumptionRecordVos);
    }

    //用户详情页面
    @GetMapping("/whetherSignToday")
    public HealthR<List<UserEntity>> whetherSignToday(@RequestHeader Integer userId){
        List<UserEntity> userEntities = userVideoService.whetherSignToday(userId);
        return HealthR.ok(userEntities);
    }
   // 用户资讯收藏列表
    @GetMapping("/findUserInfoCollectionList")
    public HealthR<List<UserInfoCollectionVo>> findUserInfoCollectionList(){
        List<UserInfoCollectionVo> userInfoCollections = userVideoService.findUserInfoCollectionList();
        return HealthR.ok(userInfoCollections);
    }
    //用户被采纳意见列表
    @GetMapping("/findMyAdoptedCommentList")
    public HealthR<List<UserAdoptCommentVo>> findMyAdoptedCommentList(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<UserAdoptCommentVo> userAdoptCommentEntities = userVideoService.findMyAdoptedCommentList();
        return HealthR.ok(userAdoptCommentEntities);
    }
    //用户查看自己的档案
    @GetMapping("/findUserArchives")
    public HealthR<List<UserArchivesVo>> findUserArchives(@RequestHeader Integer userId){
        List<UserArchivesVo> userArchivesVos = userVideoService.findUserArchives(userId);
        return HealthR.ok(userArchivesVos);
    }
    //添加用户档案
    @PostMapping("/addUserArchives")
    public HealthR addUserArchives(@RequestBody  UserArchivesEntity userArchivesEntity, @RequestHeader Integer userId){
        userVideoService.addUserArchives(userArchivesEntity,userId);
        return HealthR.ok();
    }
    //上传用户档案图片
    @PostMapping("/uploadArchivesPicture")
    public HealthR uploadUserArchivesImg(@RequestParam("imagePic") MultipartFile imagePic,
                                         @RequestHeader String sessionId,
                                         @RequestParam Integer id
                                            ){

        return HealthR.ok(userVideoService.uploadUserArchivesImg(imagePic,sessionId,id));
    }

    //用户关注医生列表
    @GetMapping("/findUserDoctorFollowList")
    public HealthR<List<UserDoctorFollowVo>> findUserDoctorFollowList(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<UserDoctorFollowVo> userDoctorFollowVos = userVideoService.findUserDoctorFollowList();
        return HealthR.ok(userDoctorFollowVos);
    }
    //用户任务列表
    @GetMapping("/findUserTaskList")
    public HealthR<List<UserTaskRecordVo>> findUserTaskList(){
        List<UserTaskRecordVo> userTaskRecordVos = userVideoService.findUserTaskList();
        return HealthR.ok(userTaskRecordVos);
    }
    //用户连续签到天数
    @GetMapping("/findUserSign")
    public HealthR<List<SignEntity>> findUserSign(@RequestHeader Integer userId){
        List<SignEntity> signEntities = userVideoService.findUserSign(userId);
        return HealthR.ok(signEntities);
    }
    //根据用户ID查询用户信息
    @GetMapping("/getUserInfoById")
    public HealthR<List<UserVo>> getUserInfoById(@RequestHeader Integer userId){
        List<UserVo> userVos = userVideoService.getUserInfoById(userId);
        return HealthR.ok(userVos);
    }
    //用户签到
    @PostMapping("/addSign")
    public HealthR addSign(){
        userVideoService.addSign();
        return HealthR.ok("签到成功");
    }
    //完善用户信息
    @PutMapping("/perfectUserInfo")
    public HealthR perfectUserInfo(@RequestParam Integer age,@RequestParam Integer height,@RequestParam  Integer weight,@RequestHeader Integer userId ){
        userVideoService.perfectUserInfo(age,height,weight,userId);
        return HealthR.ok("完善成功");
    }
    //修改用户性别
    @PutMapping("/updateUserSex")
    public HealthR updateUserSex(@RequestParam Integer sex,@RequestHeader Integer userId){
        userVideoService.updateUserSex(sex,userId);
        return HealthR.ok("修改成功");
    }
    //修改用户昵称
    @PutMapping("/modifyNickName")
    public HealthR modifyNickName(@RequestParam String nickName,@RequestHeader Integer userId){
        userVideoService.modifyNickName(nickName,userId);
        return HealthR.ok("修改成功");
    }
    //查询系统通知列表
    @GetMapping("/findSystemNoticeList")
    public HealthR<List<SystemNoticeEntity>> findSystemNoticeList(){
        List<SystemNoticeEntity> systemNoticeEntities = userVideoService.findSystemNoticeList();
        return HealthR.ok(systemNoticeEntities);
    }
    //查询用户问诊通知列表
    @GetMapping("/findInquiryNoticeList")
    public  HealthR<List<InquiryNoticeVo>> findInquiryNoticeList(@RequestHeader Integer userId,@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<InquiryNoticeVo> inquiryRecordEntities = userVideoService.findInquiryNoticeList(userId);
        return HealthR.ok(inquiryRecordEntities);
    }
    //查询用户货币通知列表
    @GetMapping("/findHealthyCurrencyNoticeList")
    public HealthR<List<HealthyCurrencyNoticeListVo>> findHealthyCurrencyNoticeList(@RequestHeader Integer userId,@RequestParam Integer page,@RequestParam Integer count) {
        startPage(page,count);
        List<HealthyCurrencyNoticeListVo> healthyCurrencyNoticeListVos = userVideoService.findHealthyCurrencyNoticeList(userId);
        return HealthR.ok(healthyCurrencyNoticeListVos);
    }

    //查询用户未读数消息
    @GetMapping("/findUserNoticeReadNum")
    public HealthR<List<UserNoticeReadNumVo>> findUserNoticeReadNum(@RequestHeader Integer userId){
        List<UserNoticeReadNumVo> userNoticeReadNumVos = userVideoService.findUserNoticeReadNum(userId);
        return HealthR.ok(userNoticeReadNumVos);
    }
    //修改消息为已读
    @PutMapping("/modifyAllStatus")
    public HealthR modifyAllStatus(@RequestHeader Integer userId){
        userVideoService.modifyAllStatus(userId);
        return HealthR.ok("全部已读");
    }
    //充值
    @PostMapping("/recharge")
    public HealthR<String> pay(@RequestParam BigDecimal money,@RequestHeader Integer userId) {
        String pay = userVideoService.Pay(money,userId);
        System.err.println(pay);
        return HealthR.ok(pay);
    }

    //提现
    @PostMapping("/drawCash")
    public HealthR drawCash(@RequestHeader Integer userId,@RequestParam BigDecimal money){
        userVideoService.drawCash(userId,money);
        return HealthR.ok("提现成功");
    }

    //病友圈评论列表查询
    @GetMapping("/findUserSickCollectionList")
    public HealthR<List<SickCircleCommentVo>> findSickCircleCommentList(@RequestHeader Integer userId,@RequestParam Integer page, @RequestParam Integer count){
        startPage(page,count);
        List<SickCircleCommentVo> sickCircleComments = userVideoService.findSickCircleCommentList(userId);
        return HealthR.ok(sickCircleComments);
    }

}
