package doctor.domain.entity;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Date;

/**
 * @ClassName : UserEntity
 * @Description : 用户表
 * @Author : FJJ
 * @Date: 2024-01-10 20:46
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class UserEntity implements Serializable {
    @NotBlank(message = "用户ID不能为空")
    private Integer id;

    @NotBlank(message = "手机号不能为空")
    @Pattern(regexp = "^1[0-9]{10}$", message = "请输入有效的手机号")
    private String phone;

    @NotBlank(message = "密码不能为空")
    @Size(min = 1, message = "密码长度不能小于1")
    private String pwd;

    @NotBlank(message = "邮箱不能为空")
    @Email(message = "请输入有效的邮箱地址")
    private String email;

    @NotBlank(message = "昵称不能为空")
    private String nickName;

    @NotBlank(message = "用户名不能为空")
    private String userName;

    private String headPic;
    private Integer sex;
    private Integer age;
    private Integer height;
    private Integer weight;
    private String  invitationCode;
    private Date updateTime;
    private Date createTime;


}
