package doctor.service.impl;

import doctor.common.core.domain.HealthR;
import doctor.common.core.web.controller.BaseController;
import doctor.common.security.service.TokenService;
import doctor.controller.HealthRVerifyController;
import doctor.domain.dto.ApplyJoinDto;
import doctor.domain.entity.*;
import doctor.domain.vo.*;
import doctor.mapper.HealthJobTitleMapper;
import doctor.service.HealthJobTitleService;
import doctor.system.api.domain.Department;
import doctor.system.api.domain.Doctor;
import doctor.system.api.model.LoginUser;
import doctor.util.OssUtil;
import doctor.util.RSAUtils;
import doctor.util.RsaKey;
import doctor.util.SendEmail;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Random;
import java.util.concurrent.TimeUnit;

@Service
public class HealthJobTitleServiceImpl extends BaseController implements HealthJobTitleService {
    @Autowired
    private HealthJobTitleMapper healthJobTitleMapper;
    @Autowired
    private SendEmail sendEmail;
    @Autowired
    private TokenService tokenService;
    @Resource
    private RedisTemplate<String,Integer> redisTemplate;

    @Override
    public List<DoctorJobTitleEntity> findJobTitleList() {
        return healthJobTitleMapper.findJobTitleList();
    }

    @Override
    public HealthR sendEmailCode(String email) {
        if (!redisTemplate.hasKey(email)){
            Integer integer = redisTemplate.opsForValue().get(email);
            sendEmail.sendEmail(email,integer);
        }
        if (email==null){
            return HealthR.fail();
        }
        Integer code=0;
        Random random = new Random();
        for (int i = 0; i < 4; i++) {
            int i1 = random.nextInt();
            code=i+=i1;
        }
        sendEmail.sendEmail(email,code);
        redisTemplate.opsForValue().set(email,code,2, TimeUnit.MINUTES);
        return HealthR.ok();
    }

    @Override
    public HealthR applyJoin(ApplyJoinDto applyJoinDto) {
        if (applyJoinDto==null){
            return HealthR.fail("参数为空");
        }
        String s="";
        try {
             s= RSAUtils.rsaDecrypt(applyJoinDto.getPwd1(), RsaKey.PRIVATE_KEY);
            String s2 = RSAUtils.rsaDecrypt(applyJoinDto.getPwd2(), RsaKey.PRIVATE_KEY);
            if (!s.equals(s2)){
                return HealthR.fail("请输入相同的密码");
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        if (!redisTemplate.hasKey(applyJoinDto.getEmail())){
            return HealthR.fail("验证码过去请重新发送");
        }
        Integer integer = redisTemplate.opsForValue().get(applyJoinDto.getEmail());
        if (!String.valueOf(integer).equals(applyJoinDto.getCode())){
            return HealthR.fail("验证码码错误");
        }
        Doctor doctor = new Doctor();
        BeanUtils.copyProperties(applyJoinDto,doctor);
        doctor.setCreateTime(new Date());
        Integer jobTitleId = applyJoinDto.getJobTitleId();
        DoctorJobTitleEntity doctorJobTitleEntity=healthJobTitleMapper.findDoctorJobTitleById(jobTitleId);
        doctor.setJobTitle(doctorJobTitleEntity.getJobTitle());
        healthJobTitleMapper.insertDoctor(doctor);
        redisTemplate.delete(applyJoinDto.getEmail());
        return HealthR.ok();
    }

    @Override
    public DoctorVo findDoctorById(Integer doctorId) {
        DoctorVo doctorVo = new DoctorVo();
        Doctor doctor=healthJobTitleMapper.findDoctorById(doctorId);
        Department department=healthJobTitleMapper.findDepartmentById(doctor.getDepartmentId());
        BeanUtils.copyProperties(doctor,doctorVo);
        BeanUtils.copyProperties(department,doctorVo);
        return doctorVo;
    }

    @Override
    public List<FindImagePicVo> findSystemImagePic() {
        ArrayList<FindImagePicVo> findImagePicVos = new ArrayList<>();
        FindImagePicVo findImagePicVo = new FindImagePicVo();
        List<String> imgPics= healthJobTitleMapper.findDoctorImgPic();
        for (String imgPic : imgPics) {
            findImagePicVo.setImagePic(imgPic);
            findImagePicVos.add(findImagePicVo);
        }
        return findImagePicVos;
    }

    @Override
    public HealthR uploadImagePic(MultipartFile imagePic,Integer doctorId,String sessionId) {
        String s = OssUtil.uploadMultipartFile(imagePic);
        healthJobTitleMapper.updDoctorImgPicBuyId(doctorId,s);
        LoginUser loginUser = tokenService.getLoginUser(sessionId);
        Doctor doctor = loginUser.getDoctor();
        doctor.setImagePic(s);
        tokenService.createToken(loginUser);
        return HealthR.ok(s);
    }

    @Override
    public HealthR checkCode(String email, String code) {
        if (email==null||email.equals("")){
            return HealthR.fail();
        }
        if (code==null||code.equals("")){
            return HealthR.fail();
        }
        if (!redisTemplate.hasKey(email)){
            return HealthR.fail();
        }
        Integer integer = redisTemplate.opsForValue().get(email);
        if (!String.valueOf(integer).equals(code)){
            return HealthR.fail();
        }
        return HealthR.ok();
    }

    @Override
    public WalletVo findDoctorWallet(Integer doctorId) {
        WalletVo walletVo=new WalletVo();
        DoctorWalletEntity doctorWalletEntity = healthJobTitleMapper.findDoctorWalletById(doctorId);
        BeanUtils.copyProperties(doctorWalletEntity,walletVo);
        walletVo.setWhetherBindIdCard(1);
        walletVo.setWhetherBindBankCard(1);
        return walletVo;
    }

    @Override
    public List<DoctorIncomeRecordVo> findDoctorIncomeRecordList(Integer doctorId, Integer page, Integer count) {
        List<DoctorIncomeRecordEntity> doctorIncomeRecordList = healthJobTitleMapper.findDoctorIncomeRecordList(doctorId);
        ArrayList<DoctorIncomeRecordVo> doctorIncomeRecordVos = new ArrayList<>();
        for (DoctorIncomeRecordEntity doctorIncomeRecordEntity : doctorIncomeRecordList) {
            DoctorIncomeRecordVo doctorIncomeRecordVo = new DoctorIncomeRecordVo();
            BeanUtils.copyProperties(doctorIncomeRecordEntity,doctorIncomeRecordVo);
            doctorIncomeRecordVos.add(doctorIncomeRecordVo);
        }
        return doctorIncomeRecordVos;
    }

    @Override
    public HealthR drawCash(Integer doctorId, Integer money) {

        return null;
    }

    @Override
    public HealthR<List<DoctorHistoryInquiryVo>> findHistoryInquiryRecord(Integer page, Integer size) {
        startPage(page,size);

        return null;
    }

    @Override
    public List<NoticeReadNumVo> findDoctorNoticeReadNum(Integer doctorId) {
        List<doctorSystemNoticeEntity> doctorSystemNoticeEntities = healthJobTitleMapper.findDoctorNoticeReadNum(doctorId);
        ArrayList<NoticeReadNumVo> noticeReadNumVos = new ArrayList<>();
        for (doctorSystemNoticeEntity doctorSystemNoticeEntity : doctorSystemNoticeEntities) {
            NoticeReadNumVo noticeReadNumVo = new NoticeReadNumVo();
            noticeReadNumVo.setNotReadNum(doctorSystemNoticeEntity.getNum());
            noticeReadNumVo.setNoticeType(doctorSystemNoticeEntity.getNoticeType());
            noticeReadNumVos.add(noticeReadNumVo);
        }
        return noticeReadNumVos;
    }

    @Override
    public List<MyAdoptedCommentListVo> findMyAdoptedCommentList(Integer doctorId, Integer page, Integer count) {
        startPage(page,count);
        return null;
    }

    @Override
    public List<DoctorSystemNoticeListVo> findDoctorSystemNoticeList(Integer page, Integer count) {
        startPage(page,count);
        List<DoctorSystemReplyEntity> doctorSystemNoticeList =  healthJobTitleMapper.findDoctorSystemNoticeList();
        ArrayList<DoctorSystemNoticeListVo> doctorSystemNoticeListVos = new ArrayList<>();
        for (DoctorSystemReplyEntity doctorSystemReplyEntity : doctorSystemNoticeList) {
            DoctorSystemNoticeListVo doctorSystemNoticeListVo = new DoctorSystemNoticeListVo();
            BeanUtils.copyProperties(doctorSystemReplyEntity,doctorSystemNoticeListVo);
            doctorSystemNoticeListVos.add(doctorSystemNoticeListVo);
        }
        return doctorSystemNoticeListVos;
    }

    @Override
    public void upImagePicByDoctorId(String imagePic, Integer doctorId) {
        healthJobTitleMapper.upImagePicByDoctorId(doctorId,imagePic);
    }
}
