package doctor.service.impl;

import doctor.common.security.utils.SecurityUtils;
import doctor.domain.entity.*;
import doctor.domain.vo.DoctorVo;
import doctor.domain.vo.InquiryDetailsRecordVo;
import doctor.mapper.InquiryMapper;
import doctor.service.InquiryService;
import doctor.system.api.domain.Doctor;
import doctor.system.api.model.LoginUser;
import doctor.util.ConvertUtil;
import doctor.util.RSAUtils;
import doctor.util.RsaKey;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.Date;
import java.util.List;

/**
 * @ClassName : InquiryServiceImpl
 * @Description :
 * @Author : FJJ
 * @Date: 2024-01-12 19:19
 */
@Service
public class InquiryServiceImpl implements InquiryService {
    @Autowired
    private InquiryMapper inquiryMapper;
    @Override
    public List<InquiryDetailsRecordVo> findHistoryInquiryRecord() {
        List<InquiryDetailsRecordEntity> inquiryDetailsRecordEntity = inquiryMapper.findHistoryInquiryRecord();
        List<InquiryDetailsRecordVo> inquiryDetailsRecordVos = ConvertUtil.entityToVoList(inquiryDetailsRecordEntity, InquiryDetailsRecordVo.class);
        return inquiryDetailsRecordVos;
    }

    @Override
    public DoctorVo findDoctorInfo(Integer doctorId) {
//        DoctorCharge doctorCharge=inquiryMapper.doctorCharge(doctorId);
//        DoctorCommentCount doctorCommentCount=inquiryMapper.doctorCommentCount(doctorId);
        return inquiryMapper.findDoctorInfo(doctorId);


    }

    @Override
    public String consultDoctor(Integer userId, Integer doctorId) {
        inquiryMapper.consultDoctor(userId,doctorId);
        String doctorUserName1 = inquiryMapper.findDoctorUserNameByDoctorId(doctorId);
        try {
            List<String> strings = RSAUtils.rsaEncrypt(doctorUserName1, RsaKey.PUBLIC_KEY);
            String doctorUserName = strings.get(0);
            System.out.println("==============="+doctorUserName);
            return doctorUserName;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void followDoctor(Integer userId, Integer doctorId) {
        if (doctorId==0){
            throw new RuntimeException("医生Id不能为空");
        }else {
            UserDoctorFollowEntity userDoctorFollowEntity = new UserDoctorFollowEntity();
            LoginUser loginUser= SecurityUtils.getLoginUser();
            Long userid = loginUser.getUserid();
            userDoctorFollowEntity.setUserId(userid);
            userDoctorFollowEntity.setDoctorId(doctorId);
            userDoctorFollowEntity.setCreateTime(new Date());
            inquiryMapper.followDoctor(userDoctorFollowEntity);

        }
    }

    //取消关注
    @Override
    public void cancelFollow(Integer userId, Integer doctorId) {
        LoginUser loginUser= SecurityUtils.getLoginUser();
        Long userid=loginUser.getUserid();
        inquiryMapper.delCancelFollow(userid,doctorId);
    }

    //结束问增
    @Override
    public void endInquiry(Integer userId, Integer recordId) {
        //检查问诊记录Id是否为空
        if (recordId == 0) {
            throw new RuntimeException("问诊记录Id不能为空");
        }
        //结束问诊,获取问诊记录信息
        InquiryRecordEntity inquiryRecordEntity = inquiryMapper.findInquiryRecordById(recordId,1);
        //结束问诊,修改问诊记录状态
        inquiryMapper.endInquiry(recordId);
        if (inquiryRecordEntity==null){
            throw new RuntimeException("没有找到该问诊记录");
        }
        //获取医生问诊次数信息
        DoctorAskCount doctorAskCount=inquiryMapper.getDoctorAskCount(inquiryRecordEntity.getDoctorId());
        // 如果医生问诊次数信息为空，表示医生首次问诊，添加新的记录
        if (doctorAskCount==null){
            doctorAskCount = new DoctorAskCount();
            doctorAskCount.setDoctorAskCount(inquiryRecordEntity.getDoctorId());
            doctorAskCount.setNumber(1);
            doctorAskCount.setUpdateTime(new Date());
            doctorAskCount.setCreateTime(new Timestamp(new Date().getTime()));
            // 添加医生问诊次数记录到数据库
            inquiryMapper.addDoctorAskCount(doctorAskCount);
        }
        else {
            // 如果医生已有问诊次数记录，增加次数并更新信息
            doctorAskCount.setNumber(doctorAskCount.getNumber() + 1);
            doctorAskCount.setUpdateTime(new Date());

            // 更新医生问诊次数记录到数据库
            inquiryMapper.updDoctorAskCount(doctorAskCount);
        }
    }
}
