package doctor.service.impl;

import com.alibaba.nacos.api.model.v2.Result;
import doctor.common.core.constant.TokenConstants;
import doctor.common.core.domain.HealthR;
import doctor.common.core.web.controller.BaseController;
import doctor.common.security.service.TokenService;
import doctor.common.security.utils.SecurityUtils;
import doctor.domain.entity.SickCircleEntity;
import doctor.domain.entity.SickCommentEntity;
import doctor.domain.entity.SymptomEntity;
import doctor.mapper.PatientMapper;
import doctor.service.PatientService;
import doctor.system.api.model.LoginUser;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @ClassName PatientServiceImpl
 * @Description 描述
 */
@Service
@Log4j2
public class PatientServiceImpl extends BaseController implements PatientService {
    @Autowired
    private PatientMapper patientMapper;

    @Override
    public HealthR<List<SickCircleEntity>> sickCircleList(Integer departmentId, Integer page, Integer count) {
        /**
         * 根据科室id获取病人圈列表
         * @param departmentId 科室id
         * @return 病人圈列表
         */
        startPage(page,count);
        List<SickCircleEntity> sickCircleEntity = patientMapper.sickCircleList(departmentId);
        return HealthR.ok(sickCircleEntity);
    }


    /**
     * 根据病人圈id获取病人圈评论列表
     * @param sickCircleId 病人圈id
     * @return 病人圈评论列表
     */
    @Override
    public HealthR<List<SickCommentEntity>> findSickCircleCommentList(Integer sickCircleId) {
          List<SickCommentEntity>  sickCommentEntity = patientMapper.findSickCircleCommentList(sickCircleId);
        return HealthR.ok(sickCommentEntity);
    }



    @Override
    public HealthR<List<SickCircleEntity>> searchSickCircle(String keyWord) {
         List<SickCircleEntity> list= patientMapper.searchSickCircle(keyWord);

        return HealthR.ok(list);
    }


    @Override
    public SickCircleEntity findSickCircleInfo(Integer id) {
        SickCircleEntity sickCircleList = patientMapper.findSickCircleInfo(id);
        return sickCircleList;
    }

    @Autowired
    HttpServletRequest httpServletRequest;
    @Autowired
    RedisTemplate<String,String> redisTemplate;


     @Autowired
    TokenService tokenService;
    private LoginUser Login() {

        String header = httpServletRequest.getHeader(TokenConstants.SESSIONID);
        LoginUser loginUser = tokenService.getLoginUser(header);
        return loginUser;
    }


    @Override
    public Result<List<SymptomEntity>> symptomList() {
        List<SymptomEntity> symptomList = patientMapper.symptomList();
        return Result.success(symptomList);
    }



}
