package doctor.service.impl;

import com.alibaba.nacos.api.model.v2.Result;
import doctor.common.core.constant.TokenConstants;
import doctor.common.core.domain.HealthR;
import doctor.common.core.utils.StringUtils;
import doctor.common.core.web.controller.BaseController;
import doctor.common.security.service.TokenService;
import doctor.domain.entity.SickCircleEntity;
import doctor.domain.vo.SearchSickCircleVo;
import doctor.domain.vo.SickCircleVo;
import doctor.domain.vo.SickCommentVo;
import doctor.domain.vo.SickInfoVo;
import doctor.mapper.SickCircleMapper;
import doctor.service.SickCircleService;
import doctor.system.api.model.LoginUser;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

@Service
public class SickCircleServiceImpl extends BaseController implements SickCircleService {

    @Autowired
    private SickCircleMapper sickCircleMapper;

    @Autowired
    HttpServletRequest httpServletRequest;
    @Autowired
    TokenService tokenService;
    @Override
    public List<SickCircleVo> findSickCircleList(Integer page, Integer size, Integer departmentId) {
        List<SickCircleEntity> list = sickCircleMapper.findSickCircleList(departmentId);
        ArrayList<SickCircleVo> sickCircleVos = new ArrayList<>();
        for (SickCircleEntity sickCircleEntity : list) {
            SickCircleVo sickCircleVo = new SickCircleVo();
            sickCircleVo.setSickCircleId(sickCircleEntity.getSickCircleId());
            BeanUtils.copyProperties(sickCircleEntity,sickCircleVo);
            sickCircleVos.add(sickCircleVo);
        }
        return sickCircleVos;
    }

    @Override
    public SickInfoVo findSickCircleInfo(Integer sickCircleId) {
        SickCircleEntity sickCircleInfo = sickCircleMapper.findSickCircleInfo(sickCircleId);
        SickInfoVo sickInfoVo = new SickInfoVo();
        BeanUtils.copyProperties(sickCircleInfo,sickInfoVo);
        return sickInfoVo;
    }

    @Override
    public SearchSickCircleVo searchSickCircle(String keyWord) {
        SearchSickCircleVo searchSickCircleVo = new SearchSickCircleVo();
        SickCircleEntity sickCircleInfo = sickCircleMapper.findSickCircleInfoByKeyWord(keyWord);
        BeanUtils.copyProperties(sickCircleInfo,searchSickCircleVo);
        return searchSickCircleVo;
    }

    @Override
    public Result<SickCommentVo> publishComment(Integer sickCircleId, String content) {
        //获取用户对象
        LoginUser login = Login();
        //获取用户id
        Long userid = login.getUserid();
        sickCircleMapper.publishComment(sickCircleId,userid, content);

        return Result.success(null);
    }

    @Override
    public HealthR<SickCircleEntity> publishSickCircle(SickCircleEntity sickCircleEntity) {
        if (StringUtils.isEmpty(sickCircleEntity.getTitle())) {
            Result.failure("标题不能为空");
        }
        if (StringUtils.isEmpty(sickCircleEntity.getTitle())) {
            Result.failure("标题不能为空");
        }
        if (StringUtils.isEmpty(sickCircleEntity.getDisease())) {
            Result.failure("症状不能为空");
        }
        if (StringUtils.isEmpty(sickCircleEntity.getDetail())) {
            Result.failure("描述不能为空");
        }
        if (StringUtils.isEmpty(sickCircleEntity.getTreatmentProcess())) {
            Result.failure("治疗过程不能为空");
        }
        LoginUser login = Login();
        sickCircleEntity.setUserId(login.getUserid());

        sickCircleMapper.publishSickCircle(sickCircleEntity);
        return HealthR.ok(sickCircleEntity);
    }

    private LoginUser Login() {

        String header = httpServletRequest.getHeader(TokenConstants.SESSIONID);
        LoginUser loginUser = tokenService.getLoginUser(header);
        return loginUser;
    }
}
