package doctor.service.impl;

import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.CertAlipayRequest;
import com.alipay.api.DefaultAlipayClient;
import com.alipay.api.domain.AlipayFundTransToaccountTransferModel;
import com.alipay.api.request.AlipayFundTransToaccountTransferRequest;
import com.alipay.api.request.AlipayTradePagePayRequest;
import com.alipay.api.response.AlipayFundTransToaccountTransferResponse;
import com.alipay.api.response.AlipayTradePagePayResponse;
import doctor.AlipayConfigProperties;
import doctor.common.core.domain.HealthR;
import doctor.common.security.service.TokenService;
import doctor.domain.dto.UserArchivesDto;
import doctor.domain.dto.UserTaskRecordDto;
import doctor.domain.entity.*;
import doctor.domain.vo.*;
import doctor.mapper.UserVideoMapper;
import doctor.model.TradePayModel;
import doctor.service.UserVideoService;
import doctor.system.api.domain.Doctor;
import doctor.system.api.model.LoginUser;
import doctor.util.ConvertUtil;
import doctor.util.OssUtil;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.util.List;
import java.util.UUID;

/**
 * @ClassName : UserVideoServiceImpl
 * @Description :
 * @Author : FJJ
 * @Date: 2024-01-10 14:34
 */
@Service
@Log4j2
public class UserVideoServiceImpl implements UserVideoService {
    @Autowired
    private UserVideoMapper userVideoMapper;

    @Autowired
    private TokenService tokenService;

    @Autowired
    private HttpServletResponse response;
    @Autowired
    private AlipayConfigProperties alipayConfigProperties;
    @Autowired
    private AlipayClient alipayClient;

    @Override
    public List<UserVideoCollectionVo> findVideoCollectionList(Integer userId) {
        List<UserVideoCollectionEntity> userVideoCollectionEntityList=userVideoMapper.findVideoCollectionList(userId);
        List<UserVideoCollectionVo> userVideoCollectionVoList = ConvertUtil.entityToVoList(userVideoCollectionEntityList, UserVideoCollectionVo.class);
        return userVideoCollectionVoList;
    }

    @Override
    public void cancelVideoCollection(Integer userId, String sessionId, Integer videoId) {
        userVideoMapper.cancelVideoCollection(videoId);
    }

    @Override
    public List<UserConsumptionRecordVo> findUserConsumptionRecordList() {
        List<UserConsumptionRecordEntity> userConsumptionRecordEntityList=userVideoMapper.findUserConsumptionRecordList();
        List<UserConsumptionRecordVo> userConsumptionRecordVoList = ConvertUtil.entityToVoList(userConsumptionRecordEntityList, UserConsumptionRecordVo.class);
        return userConsumptionRecordVoList;
    }

    @Override
    public List<UserEntity> whetherSignToday(Integer userId) {
        List<UserEntity> userEntityList=userVideoMapper.findUserEntityList(userId);
        return userEntityList;
    }

    @Override
    public List<UserInfoCollectionVo> findUserInfoCollectionList() {
        List<UserInfoCollectionEntity> userVideoCollectionEntityList=userVideoMapper.findUserInfoCollectionList();
        List<UserInfoCollectionVo> userVideoCollectionVoList = ConvertUtil.entityToVoList(userVideoCollectionEntityList, UserInfoCollectionVo.class);
        return userVideoCollectionVoList;
    }

    @Override
    public List<UserAdoptCommentVo> findMyAdoptedCommentList() {
        List<UserAdoptCommentEntity> userAdoptCommentEntityList=userVideoMapper.findMyAdoptedCommentList();
        List<UserAdoptCommentVo> userAdoptCommentVoList = ConvertUtil.entityToVoList(userAdoptCommentEntityList, UserAdoptCommentVo.class);
        return userAdoptCommentVoList;
    }

    @Override
    public List<UserArchivesVo> findUserArchives(Integer userId) {
        List<UserArchivesEntity> userArchivesEntityList=userVideoMapper.findUserArchives(userId);
        List<UserArchivesVo> userArchivesVoList = ConvertUtil.entityToVoList(userArchivesEntityList, UserArchivesVo.class);
        return userArchivesVoList;
    }

    @Override
    public void addUserArchives(UserArchivesEntity userArchivesEntity,Integer userId) {
        userVideoMapper.addUserArchives(userArchivesEntity,userId);
    }


    @Override
    public List<UserDoctorFollowVo> findUserDoctorFollowList() {
        List<UserDoctorFollowEntity> userDoctorFollowEntityList=userVideoMapper.findUserDoctorFollowList();
        List<UserDoctorFollowVo> userDoctorFollowVoList = ConvertUtil.entityToVoList(userDoctorFollowEntityList, UserDoctorFollowVo.class);
        return userDoctorFollowVoList;
    }

    @Override
    public List<UserTaskRecordVo> findUserTaskList() {
        List<UserTaskRecordDto> userTaskRecordDtos=userVideoMapper.findUserTaskList();
        List<UserTaskRecordVo> userTaskRecordVoList = ConvertUtil.entityToVoList(userTaskRecordDtos, UserTaskRecordVo.class);
        return userTaskRecordVoList;
    }

    @Override
    public List<SignEntity> findUserSign(Integer userId) {
        List<SignEntity> userEntityList=userVideoMapper.findUserSign(userId);
        return userEntityList;
    }

    @Override
    public List<UserVo> getUserInfoById(Integer userId) {
        List<UserEntity> userEntities=userVideoMapper.getUserInfoById(userId);
        List<UserVo> userVos = ConvertUtil.entityToVoList(userEntities, UserVo.class);
        return userVos;
    }

    @Override
    public void addSign() {
//        userVideoMapper.addSign(signEntity);
    }

    @Override
    public void perfectUserInfo(Integer age, Integer height, Integer weight, Integer userId) {
        userVideoMapper.perfectUserInfo(age,height,weight,userId);
    }

    @Override
    public void updateUserSex(Integer sex, Integer userId) {
        userVideoMapper.updateUserSex(sex,userId);
    }

    @Override
    public void modifyNickName(String nickName, Integer userId) {
        userVideoMapper.modifyNickName(nickName,userId);
    }

    @Override
    public List<SystemNoticeEntity> findSystemNoticeList() {
        List<SystemNoticeEntity> systemNoticeEntities=userVideoMapper.findSystemNoticeList();
        return systemNoticeEntities;
    }

    @Override
    public List<InquiryNoticeVo> findInquiryNoticeList(Integer userId) {
        List<InquiryRecordEntity> inquiryRecordEntities=userVideoMapper.findInquiryNoticeList(userId);
        List<InquiryNoticeVo> inquiryNoticeVos = ConvertUtil.entityToVoList(inquiryRecordEntities, InquiryNoticeVo.class);
        return inquiryNoticeVos;
    }

    @Override
    public List<HealthyCurrencyNoticeListVo> findHealthyCurrencyNoticeList(Integer userId) {
        List<UserWalletEntity> healthyCurrencyNoticeEntities=userVideoMapper.findHealthyCurrencyNoticeList(userId);
        List<HealthyCurrencyNoticeListVo> healthyCurrencyNoticeListVos = ConvertUtil.entityToVoList(healthyCurrencyNoticeEntities, HealthyCurrencyNoticeListVo.class);
        return healthyCurrencyNoticeListVos;
    }

    @Override
    public List<UserNoticeReadNumVo> findUserNoticeReadNum(Integer userId) {
    List<SystemNoticeEntity> userNoticeReadNumEntities=userVideoMapper.findUserNoticeReadNum(userId);
    List<UserNoticeReadNumVo> userNoticeReadNumVos = ConvertUtil.entityToVoList(userNoticeReadNumEntities, UserNoticeReadNumVo.class);
        return userNoticeReadNumVos;
    }

    @Override
    public void modifyAllStatus(Integer userId) {
        userVideoMapper.modifyAllStatus(userId);
    }

    @Override
    public HealthR uploadUserArchivesImg(MultipartFile imagePic, String sessionId, Integer id) {
        String s = OssUtil.uploadMultipartFile(imagePic);
        userVideoMapper.uploadUserArchivesImg(id,s);
        LoginUser loginUser = tokenService.getLoginUser(sessionId);
        Doctor doctor = loginUser.getDoctor();
        doctor.setImagePic(s);
        tokenService.createToken(loginUser);
        return HealthR.ok(s);
    }

    @Override
    public String Pay(BigDecimal money,Integer userId) {
        // 设置支付宝请求参数
        AlipayTradePagePayRequest alipayRequest = new AlipayTradePagePayRequest();

        // 设置返回页面的URL，用户支付成功后会跳转到这个URL
        alipayRequest.setReturnUrl(alipayConfigProperties.getReturnUrl());

        // 设置异步通知的URL，支付宝会向这个URL发送支付结果通知
        alipayRequest.setNotifyUrl(alipayConfigProperties.getNotifyUrl());

        // 构建业务参数，使用TradePayModel封装支付信息
        alipayRequest.setBizContent(TradePayModel.builder()
                .outTradeNo(UUID.randomUUID().toString().replaceAll("-", "")) // 生成商户订单号
                .totalAmount(money) // 设置订单总金额
                .subject("H币充值") // 设置订单标题
                .body("APP内虚拟货币") // 设置订单描述
                .productCode("FAST_INSTANT_TRADE_PAY") // 设置产品码，FAST_INSTANT_TRADE_PAY表示快速支付
                .build()
                .toJsonStr()); // 将TradePayModel转换为JSON字符串并设置到业务参数

        try {
            // 调用支付宝SDK发起支付请求
            AlipayTradePagePayResponse alipayTradeRefundResponse = alipayClient.pageExecute(alipayRequest);

            // 打印请求成功的日志信息
            log.info("请求成功: {}", alipayTradeRefundResponse);
            log.info("请求成功: {}", alipayTradeRefundResponse.getBody());

            // 设置响应的Content-Type为text/html;charset=UTF-8
            response.setContentType("text/html;charset=UTF-8");

            //修改金额
            userVideoMapper.updateUserWallet(money,userId);
            // 返回支付宝支付页面的HTML代码，用户浏览器将自动跳转到支付宝页面进行支付
            return alipayTradeRefundResponse.getBody();

        } catch (AlipayApiException e) {
            // 处理支付宝API异常，抛出运行时异常
            throw new RuntimeException(e);
        }
    }


    @Override
    public List<UserVideoBuyVo> findUserVideoBuyList() {
        List<UserVideoBuyEntity> userVideoCollectionEntityList=userVideoMapper.findUserVideoBuyList();
        List<UserVideoBuyVo> userVideoBuyList =  ConvertUtil.entityToVoList(userVideoCollectionEntityList, UserVideoBuyVo.class);
        return userVideoBuyList;
    }

    @Override
    public void deleteVideoBuy(Integer videoId) {
        userVideoMapper.deleteVideoBuy(videoId);
    }

    @Override
    public Integer findUserWallet(Integer userId) {
        return userVideoMapper.findUserWallet(userId);
    }

    @Override
    public void drawCash(Integer userId, BigDecimal money)  {
        AlipayConfigProperties alipayConfigProperties1 = new AlipayConfigProperties();
        //构造client
        CertAlipayRequest certAlipayRequest = new CertAlipayRequest();
        // 设置网关地址
        certAlipayRequest.setServerUrl(alipayConfigProperties1.getGatewayUrl());
        //设置应用AppId
        certAlipayRequest.setAppId(alipayConfigProperties1.getAppId());
        //设置应用私钥
        certAlipayRequest.setPrivateKey(alipayConfigProperties1.getMerchantPrivateKey());

        // 设置字符集
        certAlipayRequest.setCharset(alipayConfigProperties1.getCharset());
        // 设置签名类型
        certAlipayRequest.setSignType(alipayConfigProperties1.getSignType());
//        // 设置应用公钥证书路径
//        certAlipayRequest.setCertPath(alipayConfigProperties1.);
//        // 设置支付宝公钥证书路径
//        certAlipayRequest.setAlipayPublicCertPath(basePath + AliPayConfig.ALIPAY_CERT_PATH);
//        // 设置支付宝根证书路径
//        certAlipayRequest.setRootCertPath(basePath + AliPayConfig.ALIPAY_ROOT_CERT_PATH);
        // 构造client
        AlipayClient alipayClient = null;
        try {
            alipayClient = new DefaultAlipayClient(certAlipayRequest);
        } catch (AlipayApiException e) {
            throw new RuntimeException(e);
        }
        //请求对象
        AlipayFundTransToaccountTransferRequest request = new AlipayFundTransToaccountTransferRequest();
        // 设置请求参数
        AlipayFundTransToaccountTransferModel model = new AlipayFundTransToaccountTransferModel();
        // 金额
        model.setAmount(String.valueOf(money));
//        // 商户单号  订单id
//        model.setOutBizNo(wOrderNumber);
        // 收款方支付宝账号
//        model.setPayeeAccount(zfbName);
//        // 收款方姓名
//        model.setPayeeRealName(name);
        // 收款方账户类型
        model.setPayeeType("ALIPAY_LOGONID");
        // 备注
        model.setRemark("用户提现");
        // 设置请求参数
        request.setBizModel(model);
        AlipayFundTransToaccountTransferResponse response = null;
        try {
            response = alipayClient.certificateExecute(request);
            if (response.isSuccess()) {
                if ("10000".equals(response.getCode())) {
                    /**
                     * 转账成功   这里写自己的业务代码
                     * */
                    userVideoMapper.updateUserWallet1(money,userId);
                }
            }
        } catch (AlipayApiException e) {
            System.out.println("转账失败");
        }
    }

    @Override
    public List<SickCircleCommentVo> findSickCircleCommentList(Integer userId) {
        List<SickCircleCommentEntity> sickCircleCommentEntities = userVideoMapper.findSickCircleCommentList(userId);
        List<SickCircleCommentVo> sickCircleCommentVos = ConvertUtil.entityToVoList(sickCircleCommentEntities, SickCircleCommentVo.class);
        return sickCircleCommentVos;
    }

}
